<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../../../directorymenu.cpp" line="121"/>
        <source>Open</source>
        <translation>Nyit</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Könyvtármenü beállítás</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Kinézet</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Alapkönyvtár:</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Alapkönyvtárnév</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="92"/>
        <source>Choose Base Directory</source>
        <translation>Aapkönyvtár kijelölés</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="108"/>
        <source>Choose Icon</source>
        <translation>Ikon kijelölés</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="108"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Ikonok (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="117"/>
        <source>Directory Menu</source>
        <translation>Könyvtármenü</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="117"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Az ikon betöltése sikertelen.</translation>
    </message>
</context>
</TS>
